pipi
====

shortcut install & freeze pip packages

Usage
~~~~~

::

    pipi package_name

that command will install the package via pip & will store correct version to requirements.txt


Installation
~~~~~~~~~~~~

::

    pip install pipi
